@@ -8,8 +8,9 @@ from typing import Any, Callable, Optional, Tuple, Union
 
 import cv2
 import numpy as np
-from adbutils import AdbDevice, AdbError, Network, _AdbStreamConnection, adb
+from adbutils import AdbConnection, AdbDevice, AdbError, Network, adb
 from av.codec import CodecContext
+from av.error import InvalidDataError
 
 from .const import EVENT_FRAME, EVENT_INIT, LOCK_SCREEN_ORIENTATION_UNLOCKED
 from .control import ControlSender
@@ -27,6 +28,7 @@ class Client:
         stay_awake: bool = False,
         lock_screen_orientation: int = LOCK_SCREEN_ORIENTATION_UNLOCKED,
         connection_timeout: int = 3000,
+        encoder_name: Optional[str] = None,
     ):
         """
         Create a scrcpy client, this client won't be started until you call the start function
@@ -41,8 +43,38 @@ class Client:
             stay_awake: keep Android device awake
             lock_screen_orientation: lock screen orientation, LOCK_SCREEN_ORIENTATION_*
             connection_timeout: timeout for connection, unit is ms
+            encoder_name: encoder name, enum: [OMX.google.h264.encoder, OMX.qcom.video.encoder.avc, c2.qti.avc.encoder, c2.android.avc.encoder], default is None (Auto)
         """
+        # Check Params
+        assert max_width >= 0, "max_width must be greater than or equal to 0"
+        assert bitrate >= 0, "bitrate must be greater than or equal to 0"
+        assert max_fps >= 0, "max_fps must be greater than or equal to 0"
+        assert (
+            -1 <= lock_screen_orientation <= 3
+        ), "lock_screen_orientation must be LOCK_SCREEN_ORIENTATION_*"
+        assert (
+            connection_timeout >= 0
+        ), "connection_timeout must be greater than or equal to 0"
+        assert encoder_name in [
+            None,
+            "OMX.google.h264.encoder",
+            "OMX.qcom.video.encoder.avc",
+            "c2.qti.avc.encoder",
+            "c2.android.avc.encoder",
+        ]
 
+        # Params
+        self.flip = flip
+        self.max_width = max_width
+        self.bitrate = bitrate
+        self.max_fps = max_fps
+        self.block_frame = block_frame
+        self.stay_awake = stay_awake
+        self.lock_screen_orientation = lock_screen_orientation
+        self.connection_timeout = connection_timeout
+        self.encoder_name = encoder_name
+
+        # Connect to device
         if device is None:
             device = adb.device_list()[0]
         elif isinstance(device, str):
@@ -57,19 +89,9 @@ class Client:
         self.device_name: Optional[str] = None
         self.control = ControlSender(self)
 
-        # Params
-        self.flip = flip
-        self.max_width = max_width
-        self.bitrate = bitrate
-        self.max_fps = max_fps
-        self.block_frame = block_frame
-        self.stay_awake = stay_awake
-        self.lock_screen_orientation = lock_screen_orientation
-        self.connection_timeout = connection_timeout
-
         # Need to destroy
         self.alive = False
-        self.__server_stream: Optional[_AdbStreamConnection] = None
+        self.__server_stream: Optional[AdbConnection] = None
         self.__video_socket: Optional[socket.socket] = None
         self.control_socket: Optional[socket.socket] = None
         self.control_socket_lock = threading.Lock()
@@ -110,30 +132,35 @@ class Client:
         """
         Deploy server to android device
         """
-        jar_name = "scrcpy-server-v1.24.jar"
+        jar_name = "scrcpy-server.jar"
         server_file_path = os.path.join(
             os.path.abspath(os.path.dirname(__file__)), jar_name
         )
-        self.device.push(server_file_path, "/data/local/tmp/")
+        self.device.sync.push(server_file_path, f"/data/local/tmp/{jar_name}")
         commands = [
             f"CLASSPATH=/data/local/tmp/{jar_name}",
             "app_process",
             "/",
             "com.genymobile.scrcpy.Server",
-            "1.24",  # Scrcpy server version
-            "log_level=info",  # Log level: info, verbose...
-            f"bit_rate={self.bitrate}",  # Bitrate of video
-            f"max_size={self.max_width}",  # Max screen width (long side)
-            f"max_fps={self.max_fps}",  # Max frame per second
-            f"lock_video_orientation={self.lock_screen_orientation}",  # Lock screen orientation: LOCK_SCREEN_ORIENTATION
-            "tunnel_forward=true",  # Tunnel forward
-            "control=true",  # Control enabled
-            "display_id=0",  # Display id
-            "show_touches=false",  # Show touches
-            f"stay_awake={str(self.stay_awake).lower()}",  # Stay awake
-            "clipboard_autosync=false",  # Disable Clipboard autosync
+            "1.20",  # Scrcpy server version
+            "info",  # Log level: info, verbose...
+            f"{self.max_width}",  # Max screen width (long side)
+            f"{self.bitrate}",  # Bitrate of video
+            f"{self.max_fps}",  # Max frame per second
+            f"{self.lock_screen_orientation}",  # Lock screen orientation: LOCK_SCREEN_ORIENTATION
+            "true",  # Tunnel forward
+            "-",  # Crop screen
+            "false",  # Send frame rate to client
+            "true",  # Control enabled
+            "0",  # Display id
+            "false",  # Show touches
+            "true" if self.stay_awake else "false",  # Stay awake
+            "-",  # Codec (video encoding) options
+            self.encoder_name or "-",  # Encoder name
+            "false",  # Power off screen after server closed
         ]
-        self.__server_stream: _AdbStreamConnection = self.device.shell(
+
+        self.__server_stream: AdbConnection = self.device.shell(
             commands,
             stream=True,
         )
@@ -190,7 +217,7 @@ class Client:
                         self.last_frame = frame
                         self.resolution = (frame.shape[1], frame.shape[0])
                         self.__send_to_listeners(EVENT_FRAME, frame)
-            except BlockingIOError:
+            except (BlockingIOError, InvalidDataError):
                 time.sleep(0.01)
                 if not self.block_frame:
                     self.__send_to_listeners(EVENT_FRAME, None)
